@@ -1,4 +1,3 @@
-
 ######################################################################
 ##
 #' @title Functions from Graphical Modelling with R book
@@ -19,6 +18,6 @@
 #' 
 NULL
 
+#' @export
 #' @rdname gmwr_book
-##as.adjMAT       <- graphNEL2M
-as.adjMAT       <- gn2xm_
+as.adjMAT       <- g_gn2xm_
